.. This README is meant for consumption by humans and PyPI. PyPI can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on PyPI or github. It is a comment.

.. image:: https://github.com/collective/design.plone.ctgeneric/actions/workflows/plone-package.yml/badge.svg
    :target: https://github.com/collective/design.plone.ctgeneric/actions/workflows/plone-package.yml

.. image:: https://coveralls.io/repos/github/collective/design.plone.ctgeneric/badge.svg?branch=main
    :target: https://coveralls.io/github/collective/design.plone.ctgeneric?branch=main
    :alt: Coveralls

.. image:: https://codecov.io/gh/collective/design.plone.ctgeneric/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/collective/design.plone.ctgeneric

.. image:: https://img.shields.io/pypi/v/design.plone.ctgeneric.svg
    :target: https://pypi.python.org/pypi/design.plone.ctgeneric/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/status/design.plone.ctgeneric.svg
    :target: https://pypi.python.org/pypi/design.plone.ctgeneric
    :alt: Egg Status

.. image:: https://img.shields.io/pypi/pyversions/design.plone.ctgeneric.svg?style=plastic   :alt: Supported - Python Versions

.. image:: https://img.shields.io/pypi/l/design.plone.ctgeneric.svg
    :target: https://pypi.python.org/pypi/design.plone.ctgeneric/
    :alt: License


======================
design.plone.ctgeneric
======================

Add-on that implements AGID v2 content types rules

Features
--------

TODO
----

[] Nel v3 delle cartelle degli eventi si chiamano in modo diverso, quindi vanno rinominate (credo ci sia già un upgrade-step del v3 che lo fa).
   multimedia diventa immagini

Installation
------------

Install design.plone.ctgeneric by adding it to your buildout::

    [buildout]

    ...

    eggs =
        design.plone.ctgeneric


and then running ``bin/buildout``


Authors
-------

Provided by awesome people ;)


Contributors
------------

Put your name here, you deserve it!

- ?


Contribute
----------

- Issue Tracker: https://github.com/collective/design.plone.ctgeneric/issues
- Source Code: https://github.com/collective/design.plone.ctgeneric
- Documentation: https://docs.plone.org/foo/bar


Support
-------

If you are having issues, please let us know.
We have a mailing list located at: project@example.com


License
-------

The project is licensed under the GPLv2.
